from typing import overload
import typing

import QuantConnect
import QuantConnect.Algorithm
import QuantConnect.Algorithm.CSharp.LiveStrategy.DataType
import QuantConnect.Algorithm.CSharp.LiveStrategy.Strategies
import QuantConnect.Algorithm.CSharp.qlnet.tools
import QuantConnect.Data.Market
import QuantConnect.Statistics
import System


class DeltaCollarStrategy(System.Object):
    """This class has no documentation."""

    @property
    def HasOption(self) -> bool:
        ...

    @HasOption.setter
    def HasOption(self, value: bool):
        ...

    @property
    def BalanceNow(self) -> float:
        ...

    @BalanceNow.setter
    def BalanceNow(self, value: float):
        ...

    @property
    def Underlying(self) -> QuantConnect.Algorithm.CSharp.LiveStrategy.DataType.Underlying:
        ...

    @property
    def UnderlyingPriceNow(self) -> float:
        ...

    @UnderlyingPriceNow.setter
    def UnderlyingPriceNow(self, value: float):
        ...

    @property
    def UplineNow(self) -> float:
        ...

    @UplineNow.setter
    def UplineNow(self, value: float):
        ...

    @property
    def ExpiryDateNow(self) -> typing.Any:
        ...

    @ExpiryDateNow.setter
    def ExpiryDateNow(self, value: typing.Any):
        ...

    @property
    def TargetDelta(self) -> float:
        ...

    @TargetDelta.setter
    def TargetDelta(self, value: float):
        ...

    @property
    def CashDelta(self) -> float:
        ...

    @CashDelta.setter
    def CashDelta(self, value: float):
        ...

    @property
    def TargetUnderlyingVolume(self) -> float:
        ...

    @TargetUnderlyingVolume.setter
    def TargetUnderlyingVolume(self, value: float):
        ...

    @property
    def Options(self) -> typing.Any:
        ...

    @Options.setter
    def Options(self, value: typing.Any):
        ...

    def __init__(self, underlying: QuantConnect.Algorithm.CSharp.LiveStrategy.DataType.Underlying) -> None:
        ...

    def DetectionStrategy(self, sliceTime: typing.Any, underlyingPrice: float, priceList: typing.Any) -> typing.Any:
        ...


class DeltaCollarStrategyBear(System.Object):
    """This class has no documentation."""

    @property
    def HasOption(self) -> bool:
        ...

    @HasOption.setter
    def HasOption(self, value: bool):
        ...

    @property
    def BalanceNow(self) -> float:
        ...

    @BalanceNow.setter
    def BalanceNow(self, value: float):
        ...

    @property
    def Underlying(self) -> QuantConnect.Algorithm.CSharp.LiveStrategy.DataType.Underlying:
        ...

    @Underlying.setter
    def Underlying(self, value: QuantConnect.Algorithm.CSharp.LiveStrategy.DataType.Underlying):
        ...

    @property
    def UnderlyingPriceNow(self) -> float:
        ...

    @UnderlyingPriceNow.setter
    def UnderlyingPriceNow(self, value: float):
        ...

    @property
    def UplineNow(self) -> float:
        ...

    @UplineNow.setter
    def UplineNow(self, value: float):
        ...

    @property
    def ExpiryDateNow(self) -> typing.Any:
        ...

    @ExpiryDateNow.setter
    def ExpiryDateNow(self, value: typing.Any):
        ...

    @property
    def TargetDelta(self) -> float:
        ...

    @TargetDelta.setter
    def TargetDelta(self, value: float):
        ...

    @property
    def CashDelta(self) -> float:
        ...

    @CashDelta.setter
    def CashDelta(self, value: float):
        ...

    @property
    def OutputBaseDirectory(self) -> str:
        ...

    @OutputBaseDirectory.setter
    def OutputBaseDirectory(self, value: str):
        ...

    @property
    def Sigma(self) -> float:
        ...

    @Sigma.setter
    def Sigma(self, value: float):
        ...

    @property
    def HedgeRange(self) -> float:
        ...

    @HedgeRange.setter
    def HedgeRange(self, value: float):
        ...

    @property
    def IsDecay(self) -> bool:
        ...

    @IsDecay.setter
    def IsDecay(self, value: bool):
        ...

    @property
    def OldStrike(self) -> float:
        ...

    @OldStrike.setter
    def OldStrike(self, value: float):
        ...

    @property
    def StrategeType(self) -> int:
        """This property contains the int value of a member of the QuantConnect.Algorithm.CSharp.qlnet.tools.Utils.MoveStrikeType enum."""
        ...

    @StrategeType.setter
    def StrategeType(self, value: int):
        """This property contains the int value of a member of the QuantConnect.Algorithm.CSharp.qlnet.tools.Utils.MoveStrikeType enum."""
        ...

    @property
    def GammaLimit(self) -> float:
        ...

    @GammaLimit.setter
    def GammaLimit(self, value: float):
        ...

    @property
    def Gamma(self) -> float:
        ...

    @Gamma.setter
    def Gamma(self, value: float):
        ...

    @property
    def T2M(self) -> float:
        ...

    @T2M.setter
    def T2M(self, value: float):
        ...

    @property
    def T2MUpdateRatio(self) -> float:
        ...

    @T2MUpdateRatio.setter
    def T2MUpdateRatio(self, value: float):
        ...

    @property
    def Index(self) -> int:
        ...

    @Index.setter
    def Index(self, value: int):
        ...

    @property
    def Options(self) -> typing.Any:
        ...

    @Options.setter
    def Options(self, value: typing.Any):
        ...

    def __init__(self, underlying: QuantConnect.Algorithm.CSharp.LiveStrategy.DataType.Underlying) -> None:
        ...

    def DetectionStrategy(self, sliceTime: typing.Any, underlyingPrice: float, sigma: float, balanceNow: float = -1, stopProfit: bool = False) -> typing.Any:
        ...

    def NeedHedge(self) -> bool:
        ...


class DeltaCollarStrategyDeltaDecay(System.Object):
    """This class has no documentation."""

    @property
    def HasOption(self) -> bool:
        ...

    @HasOption.setter
    def HasOption(self, value: bool):
        ...

    @property
    def BalanceNow(self) -> float:
        ...

    @BalanceNow.setter
    def BalanceNow(self, value: float):
        ...

    @property
    def Underlying(self) -> QuantConnect.Algorithm.CSharp.LiveStrategy.DataType.Underlying:
        ...

    @Underlying.setter
    def Underlying(self, value: QuantConnect.Algorithm.CSharp.LiveStrategy.DataType.Underlying):
        ...

    @property
    def UnderlyingPriceNow(self) -> float:
        ...

    @UnderlyingPriceNow.setter
    def UnderlyingPriceNow(self, value: float):
        ...

    @property
    def UplineNow(self) -> float:
        ...

    @UplineNow.setter
    def UplineNow(self, value: float):
        ...

    @property
    def ExpiryDateNow(self) -> typing.Any:
        ...

    @ExpiryDateNow.setter
    def ExpiryDateNow(self, value: typing.Any):
        ...

    @property
    def TargetDelta(self) -> float:
        ...

    @TargetDelta.setter
    def TargetDelta(self, value: float):
        ...

    @property
    def CashDelta(self) -> float:
        ...

    @CashDelta.setter
    def CashDelta(self, value: float):
        ...

    @property
    def StrategeType(self) -> int:
        """This property contains the int value of a member of the QuantConnect.Algorithm.CSharp.qlnet.tools.Utils.MoveStrikeType enum."""
        ...

    @StrategeType.setter
    def StrategeType(self, value: int):
        """This property contains the int value of a member of the QuantConnect.Algorithm.CSharp.qlnet.tools.Utils.MoveStrikeType enum."""
        ...

    @property
    def OutputBaseDirectory(self) -> str:
        ...

    @OutputBaseDirectory.setter
    def OutputBaseDirectory(self, value: str):
        ...

    @property
    def GammaLimit(self) -> float:
        ...

    @GammaLimit.setter
    def GammaLimit(self, value: float):
        ...

    @property
    def TargetUnderlyingVolume(self) -> float:
        ...

    @TargetUnderlyingVolume.setter
    def TargetUnderlyingVolume(self, value: float):
        ...

    @property
    def PutStrikeRatio(self) -> float:
        ...

    @PutStrikeRatio.setter
    def PutStrikeRatio(self, value: float):
        ...

    @property
    def Gamma(self) -> float:
        ...

    @Gamma.setter
    def Gamma(self, value: float):
        ...

    @property
    def Sigma(self) -> float:
        ...

    @Sigma.setter
    def Sigma(self, value: float):
        ...

    @property
    def HedgeRange(self) -> float:
        ...

    @HedgeRange.setter
    def HedgeRange(self, value: float):
        ...

    @property
    def IsDecay(self) -> bool:
        ...

    @IsDecay.setter
    def IsDecay(self, value: bool):
        ...

    @property
    def Options(self) -> typing.Any:
        ...

    @Options.setter
    def Options(self, value: typing.Any):
        ...

    def __init__(self, underlying: QuantConnect.Algorithm.CSharp.LiveStrategy.DataType.Underlying) -> None:
        ...

    def DetectionStrategy(self, sliceTime: typing.Any, underlyingPrice: float, sigma: float, balanceNow: float = -1) -> typing.Any:
        ...

    def NeedHedge(self) -> bool:
        ...


class DeltaCollarStrategyFTXHedge(System.Object):
    """This class has no documentation."""

    @property
    def TargetPositions(self) -> typing.Any:
        ...

    @TargetPositions.setter
    def TargetPositions(self, value: typing.Any):
        ...

    @property
    def FTXOptions(self) -> typing.Any:
        ...

    @FTXOptions.setter
    def FTXOptions(self, value: typing.Any):
        ...

    @property
    def UnderlyingPriceNow(self) -> float:
        ...

    @UnderlyingPriceNow.setter
    def UnderlyingPriceNow(self, value: float):
        ...

    @property
    def TargetDelta(self) -> float:
        ...

    @TargetDelta.setter
    def TargetDelta(self, value: float):
        ...

    @property
    def CashDelta(self) -> float:
        ...

    @CashDelta.setter
    def CashDelta(self, value: float):
        ...

    @property
    def OptionRatio(self) -> float:
        ...

    @OptionRatio.setter
    def OptionRatio(self, value: float):
        ...

    @property
    def BalanceNow(self) -> float:
        ...

    @BalanceNow.setter
    def BalanceNow(self, value: float):
        ...

    @property
    def OutputFile(self) -> str:
        ...

    @OutputFile.setter
    def OutputFile(self, value: str):
        ...

    @property
    def PutStrategyJsonFiles(self) -> typing.List[str]:
        ...

    @PutStrategyJsonFiles.setter
    def PutStrategyJsonFiles(self, value: typing.List[str]):
        ...

    @property
    def MinStrike(self) -> float:
        ...

    @MinStrike.setter
    def MinStrike(self, value: float):
        ...

    @property
    def CostMultiplier(self) -> float:
        ...

    @CostMultiplier.setter
    def CostMultiplier(self, value: float):
        ...

    @property
    def MinOptionCostMode(self) -> int:
        """This property contains the int value of a member of the QuantConnect.Statistics.MinOptionCostMode enum."""
        ...

    @MinOptionCostMode.setter
    def MinOptionCostMode(self, value: int):
        """This property contains the int value of a member of the QuantConnect.Statistics.MinOptionCostMode enum."""
        ...

    @property
    def UseImpliedVolLimit(self) -> bool:
        ...

    @UseImpliedVolLimit.setter
    def UseImpliedVolLimit(self, value: bool):
        ...

    def __init__(self, putStrategyJsonFiles: typing.List[str], outputFile: str, optionRatio: float, transaction: QuantConnect.Algorithm.QCAlgorithm, minStrike: float, costMultiplier: float, minOptionCostMode: QuantConnect.Statistics.MinOptionCostMode, useImpliedVolLimit: bool) -> None:
        ...

    def CheckFTXOptionPositions(self) -> bool:
        ...

    def DetectionStrategy(self, sliceTime: typing.Any, underlyingPrice: float, priceList: typing.Any) -> typing.Any:
        ...

    def SetTargetPosition(self, underlyingPrice: float) -> None:
        ...

    def SetTransaction(self, transaction: QuantConnect.Algorithm.QCAlgorithm) -> None:
        ...


class DeltaCollarStrategyFTXHedgeNew(System.Object):
    """This class has no documentation."""

    @property
    def TargetPositions(self) -> typing.Any:
        ...

    @TargetPositions.setter
    def TargetPositions(self, value: typing.Any):
        ...

    @property
    def FTXOptions(self) -> typing.Any:
        ...

    @FTXOptions.setter
    def FTXOptions(self, value: typing.Any):
        ...

    @property
    def UnderlyingPriceNow(self) -> float:
        ...

    @UnderlyingPriceNow.setter
    def UnderlyingPriceNow(self, value: float):
        ...

    @property
    def TargetDelta(self) -> float:
        ...

    @TargetDelta.setter
    def TargetDelta(self, value: float):
        ...

    @property
    def CashDelta(self) -> float:
        ...

    @CashDelta.setter
    def CashDelta(self, value: float):
        ...

    @property
    def OptionRatio(self) -> float:
        ...

    @OptionRatio.setter
    def OptionRatio(self, value: float):
        ...

    @property
    def BalanceNow(self) -> float:
        ...

    @BalanceNow.setter
    def BalanceNow(self, value: float):
        ...

    @property
    def OutputFile(self) -> str:
        ...

    @OutputFile.setter
    def OutputFile(self, value: str):
        ...

    @property
    def PutStrategyJsonFiles(self) -> typing.List[str]:
        ...

    @PutStrategyJsonFiles.setter
    def PutStrategyJsonFiles(self, value: typing.List[str]):
        ...

    @property
    def MinStrike(self) -> float:
        ...

    @MinStrike.setter
    def MinStrike(self, value: float):
        ...

    @property
    def MaxStrike(self) -> float:
        ...

    @MaxStrike.setter
    def MaxStrike(self, value: float):
        ...

    @property
    def CostMultiplier(self) -> float:
        ...

    @CostMultiplier.setter
    def CostMultiplier(self, value: float):
        ...

    @property
    def MinOptionCostMode(self) -> int:
        """This property contains the int value of a member of the QuantConnect.Statistics.MinOptionCostMode enum."""
        ...

    @MinOptionCostMode.setter
    def MinOptionCostMode(self, value: int):
        """This property contains the int value of a member of the QuantConnect.Statistics.MinOptionCostMode enum."""
        ...

    @property
    def UseImpliedVolLimit(self) -> bool:
        ...

    @UseImpliedVolLimit.setter
    def UseImpliedVolLimit(self, value: bool):
        ...

    @property
    def TotalStrikes(self) -> int:
        ...

    @TotalStrikes.setter
    def TotalStrikes(self, value: int):
        ...

    def __init__(self, putStrategyJsonFiles: typing.List[str], outputFile: str, optionRatio: float, transaction: QuantConnect.Algorithm.QCAlgorithm, minStrike: float, costMultiplier: float, minOptionCostMode: QuantConnect.Statistics.MinOptionCostMode, useImpliedVolLimit: bool, totalStrikes: int, maxStrike: float) -> None:
        ...

    def CheckFTXOptionPositions(self) -> bool:
        ...

    def DetectionStrategy(self, sliceTime: typing.Any, underlyingPrice: float, hedgeSigma: float, filterSigma: float) -> typing.Any:
        ...

    def SetTargetPosition(self, underlyingPrice: float) -> None:
        ...

    def SetTransaction(self, transaction: QuantConnect.Algorithm.QCAlgorithm) -> None:
        ...


class DeltaCollarStrategyLeverage(System.Object):
    """This class has no documentation."""

    @property
    def HasOption(self) -> bool:
        ...

    @HasOption.setter
    def HasOption(self, value: bool):
        ...

    @property
    def BalanceNow(self) -> float:
        ...

    @BalanceNow.setter
    def BalanceNow(self, value: float):
        ...

    @property
    def Underlying(self) -> QuantConnect.Algorithm.CSharp.LiveStrategy.DataType.Underlying:
        ...

    @Underlying.setter
    def Underlying(self, value: QuantConnect.Algorithm.CSharp.LiveStrategy.DataType.Underlying):
        ...

    @property
    def UnderlyingPriceNow(self) -> float:
        ...

    @UnderlyingPriceNow.setter
    def UnderlyingPriceNow(self, value: float):
        ...

    @property
    def UplineNow(self) -> float:
        ...

    @UplineNow.setter
    def UplineNow(self, value: float):
        ...

    @property
    def ExpiryDateNow(self) -> typing.Any:
        ...

    @ExpiryDateNow.setter
    def ExpiryDateNow(self, value: typing.Any):
        ...

    @property
    def TargetDelta(self) -> float:
        ...

    @TargetDelta.setter
    def TargetDelta(self, value: float):
        ...

    @property
    def CashDelta(self) -> float:
        ...

    @CashDelta.setter
    def CashDelta(self, value: float):
        ...

    @property
    def OutputBaseDirectory(self) -> str:
        ...

    @OutputBaseDirectory.setter
    def OutputBaseDirectory(self, value: str):
        ...

    @property
    def TargetUnderlyingVolume(self) -> float:
        ...

    @TargetUnderlyingVolume.setter
    def TargetUnderlyingVolume(self, value: float):
        ...

    @property
    def Sigma(self) -> float:
        ...

    @Sigma.setter
    def Sigma(self, value: float):
        ...

    @property
    def HedgeRange(self) -> float:
        ...

    @HedgeRange.setter
    def HedgeRange(self, value: float):
        ...

    @property
    def IsDecay(self) -> bool:
        ...

    @IsDecay.setter
    def IsDecay(self, value: bool):
        ...

    @property
    def OldStrike(self) -> float:
        ...

    @OldStrike.setter
    def OldStrike(self, value: float):
        ...

    @property
    def StrategeType(self) -> int:
        """This property contains the int value of a member of the QuantConnect.Algorithm.CSharp.qlnet.tools.Utils.MoveStrikeType enum."""
        ...

    @StrategeType.setter
    def StrategeType(self, value: int):
        """This property contains the int value of a member of the QuantConnect.Algorithm.CSharp.qlnet.tools.Utils.MoveStrikeType enum."""
        ...

    @property
    def GammaLimit(self) -> float:
        ...

    @GammaLimit.setter
    def GammaLimit(self, value: float):
        ...

    @property
    def Gamma(self) -> float:
        ...

    @Gamma.setter
    def Gamma(self, value: float):
        ...

    @property
    def T2M(self) -> float:
        ...

    @T2M.setter
    def T2M(self, value: float):
        ...

    @property
    def T2MUpdateRatio(self) -> float:
        ...

    @T2MUpdateRatio.setter
    def T2MUpdateRatio(self, value: float):
        ...

    @property
    def Index(self) -> int:
        ...

    @Index.setter
    def Index(self, value: int):
        ...

    @property
    def Options(self) -> typing.Any:
        ...

    @Options.setter
    def Options(self, value: typing.Any):
        ...

    def __init__(self, underlying: QuantConnect.Algorithm.CSharp.LiveStrategy.DataType.Underlying) -> None:
        ...

    def DetectionStrategy(self, sliceTime: typing.Any, underlyingPrice: float, sigma: float, balanceNow: float = -1, stopProfit: bool = False) -> typing.Any:
        ...

    def NeedHedge(self) -> bool:
        ...


class DeltaCollarStrategyNew(System.Object):
    """This class has no documentation."""

    @property
    def HasOption(self) -> bool:
        ...

    @HasOption.setter
    def HasOption(self, value: bool):
        ...

    @property
    def BalanceNow(self) -> float:
        ...

    @BalanceNow.setter
    def BalanceNow(self, value: float):
        ...

    @property
    def Underlying(self) -> QuantConnect.Algorithm.CSharp.LiveStrategy.DataType.Underlying:
        ...

    @Underlying.setter
    def Underlying(self, value: QuantConnect.Algorithm.CSharp.LiveStrategy.DataType.Underlying):
        ...

    @property
    def UnderlyingPriceNow(self) -> float:
        ...

    @UnderlyingPriceNow.setter
    def UnderlyingPriceNow(self, value: float):
        ...

    @property
    def UplineNow(self) -> float:
        ...

    @UplineNow.setter
    def UplineNow(self, value: float):
        ...

    @property
    def ExpiryDateNow(self) -> typing.Any:
        ...

    @ExpiryDateNow.setter
    def ExpiryDateNow(self, value: typing.Any):
        ...

    @property
    def TargetDelta(self) -> float:
        ...

    @TargetDelta.setter
    def TargetDelta(self, value: float):
        ...

    @property
    def CashDelta(self) -> float:
        ...

    @CashDelta.setter
    def CashDelta(self, value: float):
        ...

    @property
    def TargetUnderlyingVolume(self) -> float:
        ...

    @TargetUnderlyingVolume.setter
    def TargetUnderlyingVolume(self, value: float):
        ...

    @property
    def Options(self) -> typing.Any:
        ...

    @Options.setter
    def Options(self, value: typing.Any):
        ...

    def __init__(self, underlying: QuantConnect.Algorithm.CSharp.LiveStrategy.DataType.Underlying) -> None:
        ...

    def DetectionStrategy(self, sliceTime: typing.Any, underlyingPrice: float, priceList: typing.Any) -> typing.Any:
        ...


class DeltaCollarStrategyPutOnly(System.Object):
    """This class has no documentation."""

    @property
    def HasOption(self) -> bool:
        ...

    @HasOption.setter
    def HasOption(self, value: bool):
        ...

    @property
    def BalanceNow(self) -> float:
        ...

    @BalanceNow.setter
    def BalanceNow(self, value: float):
        ...

    @property
    def Underlying(self) -> QuantConnect.Algorithm.CSharp.LiveStrategy.DataType.Underlying:
        ...

    @Underlying.setter
    def Underlying(self, value: QuantConnect.Algorithm.CSharp.LiveStrategy.DataType.Underlying):
        ...

    @property
    def UnderlyingPriceNow(self) -> float:
        ...

    @UnderlyingPriceNow.setter
    def UnderlyingPriceNow(self, value: float):
        ...

    @property
    def UplineNow(self) -> float:
        ...

    @UplineNow.setter
    def UplineNow(self, value: float):
        ...

    @property
    def ExpiryDateNow(self) -> typing.Any:
        ...

    @ExpiryDateNow.setter
    def ExpiryDateNow(self, value: typing.Any):
        ...

    @property
    def TargetDelta(self) -> float:
        ...

    @TargetDelta.setter
    def TargetDelta(self, value: float):
        ...

    @property
    def CashDelta(self) -> float:
        ...

    @CashDelta.setter
    def CashDelta(self, value: float):
        ...

    @property
    def TargetUnderlyingVolume(self) -> float:
        ...

    @TargetUnderlyingVolume.setter
    def TargetUnderlyingVolume(self, value: float):
        ...

    @property
    def Options(self) -> typing.Any:
        ...

    @Options.setter
    def Options(self, value: typing.Any):
        ...

    def __init__(self, underlying: QuantConnect.Algorithm.CSharp.LiveStrategy.DataType.Underlying) -> None:
        ...

    def DetectionStrategy(self, sliceTime: typing.Any, underlyingPrice: float, priceList: typing.Any, usdBooling: bool = True) -> typing.Any:
        ...


class DeltaCollarStrategyPutOnlyMoveStrike(System.Object):
    """This class has no documentation."""

    @property
    def HasOption(self) -> bool:
        ...

    @HasOption.setter
    def HasOption(self, value: bool):
        ...

    @property
    def BalanceNow(self) -> float:
        ...

    @BalanceNow.setter
    def BalanceNow(self, value: float):
        ...

    @property
    def Underlying(self) -> QuantConnect.Algorithm.CSharp.LiveStrategy.DataType.Underlying:
        ...

    @Underlying.setter
    def Underlying(self, value: QuantConnect.Algorithm.CSharp.LiveStrategy.DataType.Underlying):
        ...

    @property
    def UnderlyingPriceNow(self) -> float:
        ...

    @UnderlyingPriceNow.setter
    def UnderlyingPriceNow(self, value: float):
        ...

    @property
    def UplineNow(self) -> float:
        ...

    @UplineNow.setter
    def UplineNow(self, value: float):
        ...

    @property
    def ExpiryDateNow(self) -> typing.Any:
        ...

    @ExpiryDateNow.setter
    def ExpiryDateNow(self, value: typing.Any):
        ...

    @property
    def TargetDelta(self) -> float:
        ...

    @TargetDelta.setter
    def TargetDelta(self, value: float):
        ...

    @property
    def CashDelta(self) -> float:
        ...

    @CashDelta.setter
    def CashDelta(self, value: float):
        ...

    @property
    def StrategeType(self) -> int:
        """This property contains the int value of a member of the QuantConnect.Algorithm.CSharp.qlnet.tools.Utils.MoveStrikeType enum."""
        ...

    @StrategeType.setter
    def StrategeType(self, value: int):
        """This property contains the int value of a member of the QuantConnect.Algorithm.CSharp.qlnet.tools.Utils.MoveStrikeType enum."""
        ...

    @property
    def OutputBaseDirectory(self) -> str:
        ...

    @OutputBaseDirectory.setter
    def OutputBaseDirectory(self, value: str):
        ...

    @property
    def GammaLimit(self) -> float:
        ...

    @GammaLimit.setter
    def GammaLimit(self, value: float):
        ...

    @property
    def TargetUnderlyingVolume(self) -> float:
        ...

    @TargetUnderlyingVolume.setter
    def TargetUnderlyingVolume(self, value: float):
        ...

    @property
    def PutStrikeRatio(self) -> float:
        ...

    @PutStrikeRatio.setter
    def PutStrikeRatio(self, value: float):
        ...

    @property
    def Gamma(self) -> float:
        ...

    @Gamma.setter
    def Gamma(self, value: float):
        ...

    @property
    def Sigma(self) -> float:
        ...

    @Sigma.setter
    def Sigma(self, value: float):
        ...

    @property
    def Options(self) -> typing.Any:
        ...

    @Options.setter
    def Options(self, value: typing.Any):
        ...

    def __init__(self, underlying: QuantConnect.Algorithm.CSharp.LiveStrategy.DataType.Underlying, gammaLimit: float, strategyType: QuantConnect.Algorithm.CSharp.qlnet.tools.Utils.MoveStrikeType, outputBaseDirectory: str) -> None:
        ...

    def DetectionStrategy(self, sliceTime: typing.Any, underlyingPrice: float, priceList: typing.Any, usdBooling: bool = True) -> typing.Any:
        ...


class DeltaCollarStrategySigma(System.Object):
    """This class has no documentation."""

    @property
    def HasOption(self) -> bool:
        ...

    @HasOption.setter
    def HasOption(self, value: bool):
        ...

    @property
    def BalanceNow(self) -> float:
        ...

    @BalanceNow.setter
    def BalanceNow(self, value: float):
        ...

    @property
    def Underlying(self) -> QuantConnect.Algorithm.CSharp.LiveStrategy.DataType.Underlying:
        ...

    @Underlying.setter
    def Underlying(self, value: QuantConnect.Algorithm.CSharp.LiveStrategy.DataType.Underlying):
        ...

    @property
    def UnderlyingPriceNow(self) -> float:
        ...

    @UnderlyingPriceNow.setter
    def UnderlyingPriceNow(self, value: float):
        ...

    @property
    def UplineNow(self) -> float:
        ...

    @UplineNow.setter
    def UplineNow(self, value: float):
        ...

    @property
    def ExpiryDateNow(self) -> typing.Any:
        ...

    @ExpiryDateNow.setter
    def ExpiryDateNow(self, value: typing.Any):
        ...

    @property
    def TargetDelta(self) -> float:
        ...

    @TargetDelta.setter
    def TargetDelta(self, value: float):
        ...

    @property
    def CashDelta(self) -> float:
        ...

    @CashDelta.setter
    def CashDelta(self, value: float):
        ...

    @property
    def StrategeType(self) -> int:
        """This property contains the int value of a member of the QuantConnect.Algorithm.CSharp.qlnet.tools.Utils.MoveStrikeType enum."""
        ...

    @StrategeType.setter
    def StrategeType(self, value: int):
        """This property contains the int value of a member of the QuantConnect.Algorithm.CSharp.qlnet.tools.Utils.MoveStrikeType enum."""
        ...

    @property
    def OutputBaseDirectory(self) -> str:
        ...

    @OutputBaseDirectory.setter
    def OutputBaseDirectory(self, value: str):
        ...

    @property
    def GammaLimit(self) -> float:
        ...

    @GammaLimit.setter
    def GammaLimit(self, value: float):
        ...

    @property
    def TargetUnderlyingVolume(self) -> float:
        ...

    @TargetUnderlyingVolume.setter
    def TargetUnderlyingVolume(self, value: float):
        ...

    @property
    def PutStrikeRatio(self) -> float:
        ...

    @PutStrikeRatio.setter
    def PutStrikeRatio(self, value: float):
        ...

    @property
    def Gamma(self) -> float:
        ...

    @Gamma.setter
    def Gamma(self, value: float):
        ...

    @property
    def Sigma(self) -> float:
        ...

    @Sigma.setter
    def Sigma(self, value: float):
        ...

    @property
    def Options(self) -> typing.Any:
        ...

    @Options.setter
    def Options(self, value: typing.Any):
        ...

    def __init__(self, underlying: QuantConnect.Algorithm.CSharp.LiveStrategy.DataType.Underlying) -> None:
        ...

    def DetectionStrategy(self, sliceTime: typing.Any, underlyingPrice: float, sigma: float) -> typing.Any:
        ...


class DeltaCollarStrategyStopProfit(System.Object):
    """This class has no documentation."""

    @property
    def HasOption(self) -> bool:
        ...

    @HasOption.setter
    def HasOption(self, value: bool):
        ...

    @property
    def BalanceNow(self) -> float:
        ...

    @BalanceNow.setter
    def BalanceNow(self, value: float):
        ...

    @property
    def Underlying(self) -> QuantConnect.Algorithm.CSharp.LiveStrategy.DataType.Underlying:
        ...

    @Underlying.setter
    def Underlying(self, value: QuantConnect.Algorithm.CSharp.LiveStrategy.DataType.Underlying):
        ...

    @property
    def UnderlyingPriceNow(self) -> float:
        ...

    @UnderlyingPriceNow.setter
    def UnderlyingPriceNow(self, value: float):
        ...

    @property
    def UplineNow(self) -> float:
        ...

    @UplineNow.setter
    def UplineNow(self, value: float):
        ...

    @property
    def ExpiryDateNow(self) -> typing.Any:
        ...

    @ExpiryDateNow.setter
    def ExpiryDateNow(self, value: typing.Any):
        ...

    @property
    def TargetDelta(self) -> float:
        ...

    @TargetDelta.setter
    def TargetDelta(self, value: float):
        ...

    @property
    def CashDelta(self) -> float:
        ...

    @CashDelta.setter
    def CashDelta(self, value: float):
        ...

    @property
    def OutputBaseDirectory(self) -> str:
        ...

    @OutputBaseDirectory.setter
    def OutputBaseDirectory(self, value: str):
        ...

    @property
    def TargetUnderlyingVolume(self) -> float:
        ...

    @TargetUnderlyingVolume.setter
    def TargetUnderlyingVolume(self, value: float):
        ...

    @property
    def Sigma(self) -> float:
        ...

    @Sigma.setter
    def Sigma(self, value: float):
        ...

    @property
    def HedgeRange(self) -> float:
        ...

    @HedgeRange.setter
    def HedgeRange(self, value: float):
        ...

    @property
    def IsDecay(self) -> bool:
        ...

    @IsDecay.setter
    def IsDecay(self, value: bool):
        ...

    @property
    def OldStrike(self) -> float:
        ...

    @OldStrike.setter
    def OldStrike(self, value: float):
        ...

    @property
    def StrategeType(self) -> int:
        """This property contains the int value of a member of the QuantConnect.Algorithm.CSharp.qlnet.tools.Utils.MoveStrikeType enum."""
        ...

    @StrategeType.setter
    def StrategeType(self, value: int):
        """This property contains the int value of a member of the QuantConnect.Algorithm.CSharp.qlnet.tools.Utils.MoveStrikeType enum."""
        ...

    @property
    def GammaLimit(self) -> float:
        ...

    @GammaLimit.setter
    def GammaLimit(self, value: float):
        ...

    @property
    def Gamma(self) -> float:
        ...

    @Gamma.setter
    def Gamma(self, value: float):
        ...

    @property
    def Options(self) -> typing.Any:
        ...

    @Options.setter
    def Options(self, value: typing.Any):
        ...

    def __init__(self, underlying: QuantConnect.Algorithm.CSharp.LiveStrategy.DataType.Underlying) -> None:
        ...

    def DetectionStrategy(self, sliceTime: typing.Any, underlyingPrice: float, sigma: float, balanceNow: float = -1, stopProfit: bool = False) -> typing.Any:
        ...

    def NeedHedge(self) -> bool:
        ...


class PutCallParityPortfolio(System.Object):
    """This class has no documentation."""

    @property
    def CallOption(self) -> QuantConnect.Data.Market.OptionContract:
        ...

    @CallOption.setter
    def CallOption(self, value: QuantConnect.Data.Market.OptionContract):
        ...

    @property
    def PutOption(self) -> QuantConnect.Data.Market.OptionContract:
        ...

    @PutOption.setter
    def PutOption(self, value: QuantConnect.Data.Market.OptionContract):
        ...

    @property
    def FuturesSymbol(self) -> QuantConnect.Symbol:
        ...

    @FuturesSymbol.setter
    def FuturesSymbol(self, value: QuantConnect.Symbol):
        ...

    @property
    def CallQuantity(self) -> float:
        ...

    @CallQuantity.setter
    def CallQuantity(self, value: float):
        ...

    @property
    def AnnualReturn(self) -> float:
        ...

    @AnnualReturn.setter
    def AnnualReturn(self, value: float):
        ...

    def __init__(self, callOption: QuantConnect.Data.Market.OptionContract, putOption: QuantConnect.Data.Market.OptionContract, futuresSymbol: typing.Union[QuantConnect.Symbol, str], callQuantity: float, annualReturn: float) -> None:
        ...

    def ToString(self) -> str:
        ...





from typing import overload
import datetime
import typing

import QuantConnect
import QuantConnect.OptionQuote
import QuantConnect.Orders
import System
import System.Collections.Generic


class OptionInfo(System.Object):
    """This class has no documentation."""

    @property
    def Underlying(self) -> str:
        ...

    @Underlying.setter
    def Underlying(self, value: str):
        ...

    @property
    def Type(self) -> QuantConnect.OptionRight:
        ...

    @Type.setter
    def Type(self, value: QuantConnect.OptionRight):
        ...

    @property
    def Strike(self) -> float:
        ...

    @Strike.setter
    def Strike(self, value: float):
        ...

    @property
    def Expiry(self) -> datetime.datetime:
        ...

    @Expiry.setter
    def Expiry(self, value: datetime.datetime):
        ...

    def Parse(self, symbol: str) -> None:
        ...

    @staticmethod
    def ParseExpiry(expiry: str) -> datetime.datetime:
        ...

    def ToString(self) -> str:
        ...


class OptionFill(System.Object):
    """This class has no documentation."""

    @property
    def Id(self) -> int:
        ...

    @Id.setter
    def Id(self, value: int):
        ...

    @property
    def Size(self) -> float:
        ...

    @Size.setter
    def Size(self, value: float):
        ...

    @property
    def Price(self) -> float:
        ...

    @Price.setter
    def Price(self, value: float):
        ...

    @property
    def Option(self) -> QuantConnect.OptionQuote.OptionInfo:
        ...

    @Option.setter
    def Option(self, value: QuantConnect.OptionQuote.OptionInfo):
        ...

    @property
    def Time(self) -> datetime.datetime:
        ...

    @Time.setter
    def Time(self, value: datetime.datetime):
        ...

    @property
    def Liquidity(self) -> str:
        """taker or maker"""
        ...

    @Liquidity.setter
    def Liquidity(self, value: str):
        """taker or maker"""
        ...

    @property
    def Fee(self) -> float:
        ...

    @Fee.setter
    def Fee(self, value: float):
        ...

    @property
    def FeeRate(self) -> float:
        ...

    @FeeRate.setter
    def FeeRate(self, value: float):
        ...

    @property
    def Side(self) -> QuantConnect.Orders.OrderDirection:
        ...

    @Side.setter
    def Side(self, value: QuantConnect.Orders.OrderDirection):
        ...


class OptionPosition(System.Object):
    """This class has no documentation."""

    @property
    def NetSize(self) -> float:
        ...

    @NetSize.setter
    def NetSize(self, value: float):
        ...

    @property
    def EntryPrice(self) -> float:
        ...

    @EntryPrice.setter
    def EntryPrice(self, value: float):
        ...

    @property
    def Size(self) -> float:
        ...

    @Size.setter
    def Size(self, value: float):
        ...

    @property
    def Option(self) -> QuantConnect.OptionQuote.OptionInfo:
        ...

    @Option.setter
    def Option(self, value: QuantConnect.OptionQuote.OptionInfo):
        ...

    @property
    def Side(self) -> QuantConnect.Orders.OrderDirection:
        ...

    @Side.setter
    def Side(self, value: QuantConnect.Orders.OrderDirection):
        ...

    @property
    def PessimisticValuation(self) -> typing.Optional[float]:
        ...

    @PessimisticValuation.setter
    def PessimisticValuation(self, value: typing.Optional[float]):
        ...

    @property
    def PessimisticIndexPrice(self) -> typing.Optional[float]:
        ...

    @PessimisticIndexPrice.setter
    def PessimisticIndexPrice(self, value: typing.Optional[float]):
        ...

    @property
    def PessimisticVol(self) -> typing.Optional[float]:
        ...

    @PessimisticVol.setter
    def PessimisticVol(self, value: typing.Optional[float]):
        ...

    def ToString(self) -> str:
        ...


class Quote(System.Object):
    """This class has no documentation."""

    @property
    def Collateral(self) -> float:
        ...

    @Collateral.setter
    def Collateral(self, value: float):
        ...

    @property
    def Id(self) -> int:
        ...

    @Id.setter
    def Id(self, value: int):
        ...

    @property
    def Option(self) -> QuantConnect.OptionQuote.OptionInfo:
        ...

    @Option.setter
    def Option(self, value: QuantConnect.OptionQuote.OptionInfo):
        ...

    @property
    def Price(self) -> float:
        ...

    @Price.setter
    def Price(self, value: float):
        ...

    @property
    def QuoteExpiry(self) -> typing.Optional[datetime.datetime]:
        ...

    @QuoteExpiry.setter
    def QuoteExpiry(self, value: typing.Optional[datetime.datetime]):
        ...

    @property
    def QuoterSide(self) -> typing.Optional[QuantConnect.Orders.OrderDirection]:
        ...

    @QuoterSide.setter
    def QuoterSide(self, value: typing.Optional[QuantConnect.Orders.OrderDirection]):
        ...

    @property
    def RequestId(self) -> typing.Optional[int]:
        ...

    @RequestId.setter
    def RequestId(self, value: typing.Optional[int]):
        ...

    @property
    def RequestSide(self) -> typing.Optional[QuantConnect.Orders.OrderDirection]:
        ...

    @RequestSide.setter
    def RequestSide(self, value: typing.Optional[QuantConnect.Orders.OrderDirection]):
        ...

    @property
    def Size(self) -> typing.Optional[float]:
        ...

    @Size.setter
    def Size(self, value: typing.Optional[float]):
        ...

    @property
    def Status(self) -> QuantConnect.Orders.OrderStatus:
        ...

    @Status.setter
    def Status(self, value: QuantConnect.Orders.OrderStatus):
        ...

    @property
    def Time(self) -> datetime.datetime:
        ...

    @Time.setter
    def Time(self, value: datetime.datetime):
        ...

    def ToString(self) -> str:
        ...


class QuoteRequest(System.Object):
    """This class has no documentation."""

    @property
    def Id(self) -> int:
        ...

    @Id.setter
    def Id(self, value: int):
        ...

    @property
    def Option(self) -> QuantConnect.OptionQuote.OptionInfo:
        ...

    @Option.setter
    def Option(self, value: QuantConnect.OptionQuote.OptionInfo):
        ...

    @property
    def Side(self) -> QuantConnect.Orders.OrderDirection:
        ...

    @Side.setter
    def Side(self, value: QuantConnect.Orders.OrderDirection):
        ...

    @property
    def Size(self) -> float:
        ...

    @Size.setter
    def Size(self, value: float):
        ...

    @property
    def Time(self) -> datetime.datetime:
        ...

    @Time.setter
    def Time(self, value: datetime.datetime):
        ...

    @property
    def RequestExpiry(self) -> datetime.datetime:
        ...

    @RequestExpiry.setter
    def RequestExpiry(self, value: datetime.datetime):
        ...

    @property
    def Status(self) -> QuantConnect.Orders.OrderStatus:
        ...

    @Status.setter
    def Status(self, value: QuantConnect.Orders.OrderStatus):
        ...

    @property
    def HideLimitPrice(self) -> typing.Optional[bool]:
        ...

    @HideLimitPrice.setter
    def HideLimitPrice(self, value: typing.Optional[bool]):
        ...

    @property
    def LimitPrice(self) -> typing.Optional[float]:
        ...

    @LimitPrice.setter
    def LimitPrice(self, value: typing.Optional[float]):
        ...

    @property
    def Quotes(self) -> System.Collections.Generic.List[QuantConnect.OptionQuote.Quote]:
        ...

    @Quotes.setter
    def Quotes(self, value: System.Collections.Generic.List[QuantConnect.OptionQuote.Quote]):
        ...

    def ToString(self) -> str:
        ...


